#!/bin/sh

# EvoMaintenance script
# Dependencies (all OS): git postgresql-client
# Dependencies (Debian): sudo

# version 0.2
# Copyright 2007-2008 Gregory Colpart <reg@evolix.fr>, Evolix <info@evolix.fr>


test -f /etc/evomaintenance.cf && . /etc/evomaintenance.cf

[ -n "${HOSTNAME}" ] || HOSTNAME=$(hostname)
[ -n "${EVOMAINTMAIL}" ] || EVOMAINTMAIL=evomaintenance-$(echo "${HOSTNAME}" | cut -d- -f1)@${REALM}

PATH=${PATH}:/usr/sbin

# get ipaddress

BEGIN_YEAR=$(date "+%Y")

SYSTEME=$(uname -s)

if [ "${SYSTEME}" = "Linux" ]; then
    IP=$(LC_ALL=C who | grep $(ps -o tty= | tail -1) | tr -s ' ' | cut -d" " -f6 | sed -e "s/^(// ; s/)$//")
    BEGIN_DATE=$(LC_ALL=C who | grep $(ps -o tty= | tail -1) | tr -s ' ' | cut -d" " -f3,4,5)
    _USER=${SUDO_USER}
    LOGFILE_PERMS="root:adm"
elif [ "${SYSTEME}" = "OpenBSD" ]; then
    IP=$(LC_ALL=C who | grep $(env | grep SSH_TTY | cut -d"/" -f3) | tr -s ' ' | cut -d" " -f6  | sed -e "s/^(// ; s/)$//")
    BEGIN_DATE=$(LC_ALL=C who | grep $(env | grep SSH_TTY | cut -d"/" -f3) | tr -s ' ' | cut -d" " -f3,4,5)
    _USER=${USER}
    LOGFILE_PERMS="root:wheel"
else
    echo "OS not detected!"
    exit 1
fi

# log file
LOGFILE=${LOGFILE:-/var/log/evomaintenance.log}
touch "${LOGFILE}"
chown "${LOGFILE_PERMS}" "${LOGFILE}"

# end_date
NOW=$(date -u +"%Y-%m-%dT%H:%M:%SZ")

# details
echo "Please, enter details about your maintenance"
read TEXTE

if [ "${TEXTE}" = "" ]; then
    echo "no value..."
    exit 1
fi

# recapitulatif
echo "hostname = ${HOSTNAME}"
echo "user = ${_USER}"
echo "IP = ${IP}"
echo "begin date = ${BEGIN_YEAR} ${BEGIN_DATE}"
echo "details = ${TEXTE}"

echo "To cancel, [Ctrl+C] else press [Enter]"
read enter

# write log
LOG_TEXTE=$(echo "${TEXTE}" | sed 's/"/\\\"/g')

echo "${NOW} hostname=\"${HOSTNAME}\" user=\"${SUDO_USER}\" ip=\"${IP}\" begin_date=\"${BEGIN_YEAR} ${BEGIN_DATE}\" message=\"${LOG_TEXTE}\"" >> "${LOGFILE}"

# git commit
GIT_BIN=$(command -v git)

if test -x "${GIT_BIN}"; then
    export GIT_DIR=/etc/.git
    ${GIT_BIN} add .
    ${GIT_BIN} commit --all --message "${LOG_TEXTE}" --author="${_USER} <${_USER}@evolix.net>" --quiet
fi

# insert into PG
SQL_TEXTE=`echo "${TEXTE}" | sed "s/'/\\\\\\'/g ; s@/@\\\\\/@g ; s@\\&@et@g"`

echo "
INSERT INTO evomaint(hostname,userid,ipaddress,begin_date,end_date,details)
VALUES ('${HOSTNAME}','${_USER}','${IP}','${BEGIN_YEAR} ${BEGIN_DATE}',now(),'${SQL_TEXTE}') " | \
    psql ${PGDB} ${PGTABLE} -h ${PGHOST}

# send mail
SENDMAIL=$(command -v sendmail)

cat /usr/share/scripts/evomaintenance.tpl | \
    sed -e "s/__TO__/${EVOMAINTMAIL}/ ; s/__HOSTNAME__/${HOSTNAME}/ ; s/__USER__/${_USER}/ ; s/__BEGIN_DATE__/${BEGIN_YEAR} ${BEGIN_DATE}/ ; s/__TEXTE__/${TEXTE}/ ; s/__IP__/${IP}/ ; s/__FULLFROM__/${FULLFROM}/ ; s/__FROM__/${FROM}/ ; s/__URGENCYFROM__/${URGENCYFROM}/ ; s/__URGENCYTEL__/${URGENCYTEL}/" | \
    ${SENDMAIL} -oi -t -f ${FROM}
